/*! 
    \file physics_connection.h
    \brief Definition of The Physical Connection Class.
*/

#ifndef _PHYSICS_CONNECTION_H 
#define _PHYSICS_CONNECTION_H

#include "base_object.h"

//! An enumerator for different ConnectionTypes
typedef enum PCON_Type { PCON_IPhysIPhys = 0,
			 PCON_IPhysField = 1,
			 PCON_ParticlesField = 2 };


// Forward Declaration
class Field;
class IPhysics;
class ParticleSystem;


typedef struct PhysConnection
{
  PCON_Type type;                    //!< What kind of connection this is.

  IPhysics* subject;                 //!< The main Subject of this Connection.
  IPhysics* partner2;                //!< The second partner of this Connection.

  ParticleSystem* particleSystem;    //!< A ParticleSystem in this Connection
  
  Field* field;                      //!< The field to connect either subject of ParticleSystem to.
};

//! A class that Handles Physical Connection between subjects
class PhysicsConnection : public BaseObject {

 public:
  PhysicsConnection();
  virtual ~PhysicsConnection();

  bool addConnection(IPhysics* partnerOne, IPhysics* partnerTwo);
  bool addConnection(IPhysics* subject, Field* field);
  bool addConnection(ParticleSystem* particleSystem, Field* field);

  inline PhysConnection* getConnection(void) const {return this->connection;}

 private:
  PhysConnection* connection;        //!< The Physical Connection.
};

#endif /* _PHYSICS_CONNECTION_H */
